<?php
/**
 * @brief		Admin CP Group Form
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	Profile Songs
 * @since		13 Oct 2019
 */

namespace IPS\profilesongs\extensions\core\GroupForm;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * Admin CP Group Form
 */
class _profilesongs
{
	/**
	 * Process Form
	 *
	 * @param	\IPS\Helpers\Form		$form	The form
	 * @param	\IPS\Member\Group		$group	Existing Group
	 * @return	void
	 */
	public function process( &$form, $group )
	{
		if( $group->g_id != \IPS\Settings::i()->guest_group )
		{
			try
			{
				$loadSettings = \IPS\profilesongs\ProfileSongs\GroupSettings::load( $group->g_id, 'group_id' );
			}
			catch( \Exception $e )
			{
				$loadSettings = FALSE;
			}
			
			$form->add( new \IPS\Helpers\Form\YesNo( 'profilesongs_can_use', $loadSettings ? $loadSettings->can_use : 1, FALSE, array('togglesOn' => array( 'profilesongs_upload_limit', 'profilesongs_multiple_uploads', 'profilesongs_maximum_files' ) ) ) );
			$form->add( new \IPS\Helpers\Form\Number( 'profilesongs_upload_limit', $loadSettings ? $loadSettings->upload_limit : 10000, TRUE, array( ), NULL, NULL, 'k/b', 'profilesongs_upload_limit' ) );
			$form->add( new \IPS\Helpers\Form\Number( 'profilesongs_multiple_uploads', $loadSettings ? $loadSettings->multiple_uploads : 5, TRUE, array( ), NULL, NULL, NULL, 'profilesongs_multiple_uploads' ) );
			$form->add( new \IPS\Helpers\Form\Number( 'profilesongs_maximum_files', $loadSettings ? $loadSettings->maximum_files : 10, TRUE, array( ), NULL, NULL, NULL, 'profilesongs_maximum_files' ) );
		}
	}
	
	/**
	 * Save
	 *
	 * @param	array				$values	Values from form
	 * @param	\IPS\Member\Group	$group	The group
	 * @return	void
	 */
	public function save( $values, &$group )
	{
		if( $group->g_id != \IPS\Settings::i()->guest_group )
		{
			try
			{
				$loadSettings = \IPS\profilesongs\ProfileSongs\GroupSettings::load( $group->g_id, 'group_id' );
			}
			catch( \Exception $e )
			{
				$loadSettings = new \IPS\profilesongs\ProfileSongs\GroupSettings;
				$loadSettings->group_id = $group->g_id;
			}
			
			$loadSettings->can_use = $values['profilesongs_can_use'];
			$loadSettings->upload_limit = $values['profilesongs_upload_limit'];
			$loadSettings->multiple_uploads = $values['profilesongs_multiple_uploads'];
			$loadSettings->maximum_files = $values['profilesongs_maximum_files'];
			$loadSettings->save();
		}
	}
}