<?php
/**
 * @brief		Member Sync
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	Profile Songs
 * @since		05 Oct 2019
 */

namespace IPS\profilesongs\extensions\core\MemberSync;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * Member Sync
 */
class _ProfileSongs
{
	/**
	 * Member is merged with another member
	 *
	 * @param	\IPS\Member	$member		Member being kept
	 * @param	\IPS\Member	$member2	Member being removed
	 * @return	void
	 */
	public function onMerge( $member, $member2 )
	{
		\IPS\Db::i()->update( 'profilesongs_files', array( 'member_id' => $member->member_id ), array( 'member_id=?', $member2->member_id ) );
		\IPS\Db::i()->update( 'profilesongs_playlists', array( 'member_id' => $member->member_id ), array( 'member_id=?', $member2->member_id ) );
	}
	
	/**
	 * Member is deleted
	 *
	 * @param	$member	\IPS\Member	The member
	 * @return	void
	 */
	public function onDelete( $member )
	{
		try
		{
			foreach( \IPS\Db::i()->select( '*', 'profilesongs_files', array( 'member_id=?', $member->member_id ) ) as $file )
			{
				try
				{
					\IPS\File::get( 'profilesongs_FileStorage', $file['location'] )->delete();
				}
				catch( \Exception $e ){}
			}
		}
		catch( \Exception $e ){}
		
		\IPS\Db::i()->delete( 'profilesongs_files', array( 'member_id=?', $member->member_id ) );
	}
}