<?php
/**
 * @brief		Members Shop Extension: profileSongs
 * @author		<a href='https://www.ipsdev.org'>IPSDev</a>
 * @copyright	(c) ipsdev.org
 * @package		Members Shop
 * @subpackage	Profile Songs
 * @since		13 Oct 2019
**/

namespace IPS\profilesongs\extensions\membersshop\Items;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

class _profileSongs
{
	public static function isActive()
    {
        return TRUE;
    }
	
	/** 
	  *	This function is for the items list in the add items page of the ACP
	  *	These will be added to the array list for the select $form settings, you need to edit the 1234 in the $options[1234] to a unique id
	  *	The best way to create a unique id will be to use the unix timestamp of your current time, There is more chance of winning the lottery then 2 or more devs creating a item at the same time
	  *	You can add multiple items here just make sure each item has a unique id
	  * If you are adding multiple items just +1 the unix timestamp so if it ends 69 change it to 70
	**/
	public function itemOptions( &$options )
    {
		$options[1570989360] = \IPS\Member::loggedIn()->language()->addToStack( 'profilesongs_membersshop_item' ); // Edit the 1234 ( READ ABOVE TO WHAT ) and the language string
	}
	
	/** 
	  *	This function is for saving the values of the $form from the settings above
	  * These are the default values what will get added when created
	  * Once created the user will be directed to edit it anyway so it don't really matter what default values you put as long as it is is acceptable
	  *	If you have added multiple $options from the itemOptions function then you will need to add elseif statements below for them
	  * Any NULL values are not required but can be used in the processRedeem function below to pull data or values needed to run your script
	**/
	public function itemFormSubmitted( $values, $item )
	{
		if ( $values['ms_add_item_to_shop'] == 1570989360 ) // Edit the 1234 to the $options[] you created in the itemOptions function, DO NOT EDIT THE $values['ms_add_item_to_shop']
		{
			$item->name = \IPS\Member::loggedIn()->language()->get( 'profilesongs_membersshop_item' ); // Change the language string to match the one in the itemOptions function
			$item->price = 2500; // Set a price for the item
			$item->open = 1; // DO NOT EDIT THIS LINE
			$item->purchases = 0; // DO NOT EDIT THIS LINE
			$item->desc = 'Upload Songs to Your Profile'; // Enter a brief description to give the admin some information of what the item does
			$item->icon = 'fa-music'; // Font-Awesome icon for the item
			$item->instock = -1; // -1 is unlimited
			$item->cat_id = \IPS\Request::i()->parent; // DO NOT EDIT THIS LINE
			$item->submitted = time(); // DO NOT EDIT THIS LINE
			$item->item_id = $values['ms_add_item_to_shop']; // DO NOT EDIT THIS LINE
			
			/* The 4 values listed below are not required but might be needed for additional information to be passed onto the processRedeem function */
			$item->maxRand = NULL; // INT 255 column to use for maybe random amounts for the minimum amount 
			$item->minRand = NULL; // INT 255 column to use for maybe random amounts for the maximum amount 
			$item->extra_field = NULL; // INT 255 colums used to store any other numbers needed to be stored
			$item->extra_field_text = NULL; // VCHAR 999 Column to add additional text for the items
			
			/* DO NOT EDIT THE LINES BELOW */
			$item->save();
			\IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=membersshop&module=shop&controller=items&subnode=1&do=form&id='.$item->id.'' ), 'saved' );
		}
	}
	
	/** 
	  *	This function is for allowing the users to edit the values of the items, Any required settings will already be shown on the edit page
	  *	If you have added multiple $options from the itemOptions function then you will need to add elseif statements below for them
	  * You only need to use this function if you are using any of the non required columns listed in the itemFormSubmitted function
	**/
	public function editFormSettings( &$form, $item )
    {		
		/*
		if ( $item->item_id == 1234 ) // Edit the 1234 to match your unique id in the itemOptions function
		{
	    	$form->add( new \IPS\Helpers\Form\Number( 'my_settings', $item->minRand, TRUE, array( 'min' => 0 ), NULL, NULL, NULL, 'my_settings' ) );
			$form->add( new \IPS\Helpers\Form\Number( 'my_settings_two', $item->maxRand, TRUE, array( 'min' => 0 ), NULL, NULL, NULL, 'my_settings_two' ) );
			$form->add( new \IPS\Helpers\Form\Number( 'my_settings_three', $item->extra_field, TRUE, array( 'min' => 0 ), NULL, NULL, NULL, 'my_settings_three' ) );
			$form->add( new \IPS\Helpers\Form\Text( 'my_settings_four', $item->extra_field_text, TRUE, array( 'min' => 0 ), NULL, NULL, NULL, 'my_settings_four' ) );
		}
		*/
	}
	
	/** 
	  *	This function is for when a admin generates a purchase for a user, Any required columns will process automatically
	  *	If you have added multiple $options from the itemOptions function then you will need to add elseif statements below for them
	  * The $values are your settings values in the editFormSettings function
	  * You only need to use this function if you are using any of the non required columns listed in the itemFormSubmitted function
	**/
	public function processGenerateForm( $values, $purchase, $item )
    {		
		/*
		if ( $item->item_id == 1234 ) // Edit the 1234 to match your unique id in the itemOptions function
		{
			$purchase->minRand = $values['my_settings']; 
			$purchase->maxRand = $values['my_settings_two'];
			$purchase->extra_field = $values['my_settings_three'];
			$purchase->extra_field_text = $values['my_settings_four'];
			$purchase->save();
		}
		*/
	}
	
	/** 
	  *	This function is for saving a edited item, Any required columns will save automatically, the $values are from your settings in the editFormSettings function
	  *	If you have added multiple $options from the itemOptions function then you will need to add elseif statements below for them
	  * You only need to use this function if you are using any of the non required columns listed in the itemFormSubmitted function
	**/
	public function processEditForm( $item, $values )
    {		
		/*
		if ( $item->item_id == 1234 ) // Edit the 1234 to match your unique id in the itemOptions function
		{
			$item->minRand = $values['my_settings'];
			$item->maxRand = $values['my_settings_two'];
			$item->extra_field = $values['my_settings_three'];
			$item->extra_field_text = $values['my_settings_four'];
			$item->save();
		}
		*/
	}
	
	/** 
	  *	This function is for when a user redeems the item we are going to redirect them to the processRedeem function
	  * If you have added multiple $options from the itemOptions function then you will need to add elseif statements below for them
	**/
	public function redeemItem( $item_id, $getItem, $member, $boughtAndUsed, $categoryURL )
	{		
		if ( $item_id == 1570989360 ) { return $this->processRedeem( $getItem, $member, $boughtAndUsed, $categoryURL ); } // Edit the 1234 to match your unique id in the itemOptions function
	}
	
	/** 
	  *	This function is the actual process of the redemption of the items, the $getItem will call all the data stored in the database
	  *	If you have added multiple $options from the itemOptions function then you will need to add elseif statements below for them
	**/
	public function processRedeem( $getItem, $member, $boughtAndUsed, $categoryURL )
	{		
		if ( $getItem->item_id == 1570989360 ) // Edit the 1234 to match your unique id in the itemOptions function
		{
			/* This is where you will run your script for the item being redeemed */
			
			$maxFileSize = $member->profileSongsUploadSizeLimit() / 1024;
			$totalUploadLimit = $member->profileSongsMultipleUploads();
			
			$form = new \IPS\Helpers\Form;
			$form->class = 'ipsPad ipsBox ipsForm_noLabels ipsForm_fullWidth';
			$form->actionButtons[0] = \IPS\Theme::i()->getTemplate( 'forms', 'core', 'global' )->button( 'ms_upload', 'submit', null, 'ipsButton ipsButton_primary', array( 'tabindex' => '2', 'accesskey' => 's', 'data-action' => 'redeemOthers' ) );
			$form->add( new \IPS\Helpers\Form\Upload( 'ProfileSongsUpload', NULL, FALSE, array( 
				'multiple' => TRUE,
				'maxFiles' => $totalUploadLimit,
				'allowedFileTypes' => array ( 'mp3', 'mp4', 'ogg' ),
				'storageExtension' => 'profilesongs_FileStorage',
				'maxFileSize' => $maxFileSize ), 
			NULL, NULL, NULL, "ProfileSongsUpload" ) );
		
			if ( $values = $form->values() )
			{
				foreach( $values['ProfileSongsUpload'] as $val )
				{
					$track = new \IPS\profilesongs\ProfileSongs;
					$track->location = $val;
					$track->member_id = $member->member_id;
					$track->save();
					$audio = \IPS\File::get( 'profilesongs_FileStorage', $track->location );
					$track->name = $audio->originalFilename;
					$track->save();
				}
				
				$getItem->redeemed = 1;
				$getItem->save();
				
				/* You also need to add a output message for the user once the items redeemed so edit the language string */
				$outputLang = \IPS\Member::loggedIn()->language()->addToStack( 'saved' );
				
				if ( \IPS\Request::i()->isAjax() )
				{
					\IPS\Output::i()->json( array( 'message' => $outputLang ));
					return;
				}
				else
				{
					if ( $boughtAndUsed )
					{
						$redirectURL = $categoryURL;
					}
					else
					{
						$redirectURL = \IPS\Request::i()->referrer() ?: \IPS\Http\Url::internal( 'app=membersshop&module=shop&controller=myitems', 'front', 'myitems' );
					}
					\IPS\Output::i()->redirect( $redirectURL, $outputLang );
				}
			}
			
			if ( \IPS\Request::i()->isAjax() )
			{
				\IPS\Output::i()->json( array(
					'contents' 	=> $form->customTemplate( array( \IPS\Theme::i()->getTemplate( 'shop', 'membersshop' ), 'settingsForm' ), $getItem->name )
				)) ;
				return;
			}
			else
			{
				\IPS\Output::i()->output = $form->customTemplate( array( \IPS\Theme::i()->getTemplate( 'shop', 'membersshop' ), 'settingsForm' ), $getItem->name );
			}
		}
	}
}