//<?php

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	exit;
}

class profilesongs_hook_MembersProfileHook extends _HOOK_CLASS_
{
	protected function manage()
	{
		parent::manage();
		
		try
		{
			$memberSettings = \IPS\profilesongs\ProfileSongs\Settings::load( $this->member->member_id, 'member_id' );
		}
		catch( \Exception $e )
		{
			$memberSettings = FALSE;
		}
		
		$membersColour = $memberSettings ? $memberSettings->colour : '00FFFF';
		$membersAutoplay = $memberSettings ? $memberSettings->auto_play : FALSE;
		
		\IPS\Output::i()->jsVars['ps_member_id']  = $this->member->member_id;
		\IPS\Output::i()->jsVars['ps_member_colour']  = $membersColour;
		\IPS\Output::i()->jsVars['ps_member_autoplay']  = $membersAutoplay;
		\IPS\Output::i()->jsVars['ps_total_tracks']  = \count( $this->member->profileSongs() );
		\IPS\Output::i()->cssFiles = array_merge( \IPS\Output::i()->cssFiles, \IPS\Theme::i()->css( 'profilesongs.css', 'profilesongs', 'front' ) );
		\IPS\Output::i()->jsFiles = array_merge( \IPS\Output::i()->jsFiles, \IPS\Output::i()->js( 'global_profilesongs.js', 'profilesongs', 'global' ) );
		return;
	}
	
	protected function uploadProfileSong()
	{
		$member = $this->member;
		$loggedIn = \IPS\Member::loggedIn();
		
		if( $member->member_id != $loggedIn->member_id AND !$loggedIn->modPermission('can_modify_profiles') )
		{
			\IPS\Output::i()->error( 'profilesongs_member_upload_error', 'ProfileSongs/1', 404, '' );
		}
		
		if ( !$member->profileSongsCanUse() AND !$loggedIn->modPermission('can_modify_profiles') )
		{
		    \IPS\Output::i()->error( 'profilesongs_group_upload_error', 'ProfileSongsGroups/1', 403, '' );
		}
		
		$count = \IPS\Db::i()->select( 'COUNT(*)', 'profilesongs_files', array( 'member_id=?', $member->member_id ) )->first();
		if( $count >= $member->profileSongsMaximumFiles() )
		{
			\IPS\Output::i()->error( 'profilesongs_upload_error_max_tracks', 'ProfileSongsMaxTracks/1', 403, '' );
		}
		
		$maxFileSize = $member->profileSongsUploadSizeLimit() / 1024;
		$totalUploadLimit = $member->profileSongsMultipleUploads();
		$totalFilesRemaining = $member->profileSongsMultipleUploads() - $count;
		if( $totalFilesRemaining <= $totalUploadLimit  )
		{
			$totalUploadLimit = $totalFilesRemaining;
		}
		
		$form = new \IPS\Helpers\Form;
		$form->class = 'ipsPad ipsBox ipsForm_noLabels ipsForm_fullWidth';
		$form->add( new \IPS\Helpers\Form\Upload( 'ProfileSongsUpload', NULL, FALSE, array( 
			'multiple' => TRUE,
			'maxFiles' => $totalUploadLimit,
			'allowedFileTypes' => array ( 'mp3', 'mp4', 'ogg' ),
			'storageExtension' => 'profilesongs_FileStorage',
			'maxFileSize' => $maxFileSize ), 
		NULL, NULL, NULL, "ProfileSongsUpload" ) );
		
		if ( $values = $form->values() )
		{
			foreach( $values['ProfileSongsUpload'] as $val )
			{
				$track = new \IPS\profilesongs\ProfileSongs;
				$track->location = $val;
				$track->member_id = $member->member_id;
				$track->save();
				$audio = \IPS\File::get( 'profilesongs_FileStorage', $track->location );
				$track->name = $audio->originalFilename;
				$track->save();
			}
			
			\IPS\Output::i()->redirect( $member->url() );
		}
		
		\IPS\Output::i()->output = $form;
	}
}
