<?php


namespace IPS\profilesongs\modules\front\main;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * files
 */
class _files extends \IPS\Dispatcher\Controller
{
	/**
	 * Execute
	 *
	 * @return	void
	 */
	public function execute()
	{
		
		parent::execute();
	}

	/**
	 * ...
	 *
	 * @return	void
	 */
	protected function manage()
	{
		
	}
	
	protected function updatePosition()
	{
		$order = \IPS\Request::i()->order;
		$idx = 1;
		
		foreach( explode( ',', $order ) as $ord )
		{
			\IPS\Db::i()->update( 'profilesongs_files', array( 'position' => $idx++ ), array( 'id=?', $ord ) );
		}
		
		if( \IPS\Request::i()->isAjax() )
		{
			\IPS\Output::i()->json( 'OK' );
		}
	}
	
	protected function editTitle()
	{
		$title = \IPS\Request::i()->title;
		$id = \IPS\Request::i()->id;
		
		$maxLength	= 255;
		
		if( \strlen( \IPS\Request::i()->title ) > $maxLength )
		{
			throw new \LengthException( \IPS\Member::loggedIn()->language()->addToStack( 'form_maxlength', FALSE, array( 'pluralize' => array( $maxLength ) ) ) );
		}
		elseif( !trim( \IPS\Request::i()->title ) )
		{
			throw new \InvalidArgumentException('form_required');
		}
		
		$track = \IPS\profilesongs\ProfileSongs::load( $id );
		$track->name = $title;
		$track->save();
		
		if( \IPS\Request::i()->isAjax() )
		{
			\IPS\Output::i()->json( 'OK' );
		}
	}
	
	protected function changeColours()
	{
		$colour = \IPS\Request::i()->colour;
		$memberID = \IPS\Request::i()->member_id;
		$member = \IPS\Member::loggedIn();
		
		try
		{
			$memberSettings = \IPS\profilesongs\ProfileSongs\Settings::load( $memberID, 'member_id' );
		}
		catch( \Exception $e )
		{
			$memberSettings = new \IPS\profilesongs\ProfileSongs\Settings;
		}
		
		$memberSettings->colour = $colour;
		$memberSettings->colour_solid = 0;
		$memberSettings->member_id = $memberID;
		$memberSettings->save();
		
		if( \IPS\Request::i()->isAjax() )
		{
			\IPS\Output::i()->json( 'OK' );
		}
	}
	
	protected function changeColoursSolid()
	{
		$colour = \IPS\Request::i()->colour;
		$member = \IPS\Member::loggedIn();
		$memberID = \IPS\Request::i()->member_id;
		
		try
		{
			$memberSettings = \IPS\profilesongs\ProfileSongs\Settings::load( $memberID, 'member_id' );
		}
		catch( \Exception $e )
		{
			$memberSettings = new \IPS\profilesongs\ProfileSongs\Settings;
		}
		
		$memberSettings->colour = $colour;
		$memberSettings->colour_solid = 1;
		$memberSettings->member_id = $memberID;
		$memberSettings->save();
		
		if( \IPS\Request::i()->isAjax() )
		{
			\IPS\Output::i()->json( 'OK' );
		}
	}
	
	protected function deleteTrack()
	{
		$id = \IPS\Request::i()->id;
		$member = \IPS\Member::loggedIn();
		$track = \IPS\profilesongs\ProfileSongs::load( $id );
		
		if( $track->member_id == $member->member_id AND !$track->playlist_id OR $member->modPermission('can_modify_profiles') AND !$track->playlist_id )
		{
			$tracksFile = \IPS\File::get( 'profilesongs_FileStorage', $track->location );
			$tracksFile->delete();
			
			\IPS\Db::i()->delete( 'profilesongs_files', array( 'location=?', $track->location ) );
			
			if( \IPS\Request::i()->isAjax() )
			{
				\IPS\Output::i()->json( 'OK' );
			}
		}
		elseif( $track->member_id == $member->member_id AND $track->playlist_id OR $member->modPermission('can_modify_profiles') AND $track->playlist_id )
		{
			$track->delete();
			
			if( \IPS\Request::i()->isAjax() )
			{
				\IPS\Output::i()->json( 'OK' );
			}
		}
	}
	
	protected function autoplayToggle()
	{
		$memberID = \IPS\Request::i()->member_id;
		$member = \IPS\Member::loggedIn();
		
		if( $memberID == $member->member_id OR $member->modPermission('can_modify_profiles') )
		{
			try
			{
				$memberSettings = \IPS\profilesongs\ProfileSongs\Settings::load( $memberID, 'member_id' );
			}
			catch( \Exception $e )
			{
				$memberSettings = new \IPS\profilesongs\ProfileSongs\Settings;
				$memberSettings->member_id = $memberID;
			}
			
			if( $memberSettings->auto_play )
			{
				$memberSettings->auto_play = 0;
				$memberSettings->save();
				if( \IPS\Request::i()->isAjax() )
				{
					\IPS\Output::i()->json( 'disabled' );
				}
			}
			else
			{
				$memberSettings->auto_play = 1;
				$memberSettings->save();
				if( \IPS\Request::i()->isAjax() )
				{
					\IPS\Output::i()->json( 'enabled' );
				}
			}
		}
	}
	
	protected function sharingToggle()
	{
		$memberID = \IPS\Request::i()->member_id;
		$member = \IPS\Member::loggedIn();
		
		if( $memberID == $member->member_id OR $member->modPermission('can_modify_profiles') )
		{
			try
			{
				$memberSettings = \IPS\profilesongs\ProfileSongs\Settings::load( $memberID, 'member_id' );
			}
			catch( \Exception $e )
			{
				$memberSettings = new \IPS\profilesongs\ProfileSongs\Settings;
				$memberSettings->member_id = $memberID;
			}
			
			if( $memberSettings->enable_sharing )
			{
				$memberSettings->enable_sharing = 0;
				$memberSettings->save();
				if( \IPS\Request::i()->isAjax() )
				{
					\IPS\Output::i()->json( 'disabled' );
				}
			}
			else
			{
				$memberSettings->enable_sharing = 1;
				$memberSettings->save();
				if( \IPS\Request::i()->isAjax() )
				{
					\IPS\Output::i()->json( 'enabled' );
				}
			}
		}
	}
	
	protected function addToPlaylist()
	{
		$id = \IPS\Request::i()->id;
		$member = \IPS\Member::loggedIn();
		$track = \IPS\profilesongs\ProfileSongs::load( $id );
		
		try
		{
			$alreadyGot = \IPS\Db::i()->select( '*', 'profilesongs_files', array( 'member_id=? AND location=?', $member->member_id, $track->location ) )->first();
		}
		catch( \Exception $ex )
		{
			$alreadyGot = FALSE;
		}
		
		if( !$alreadyGot )
		{
			$newTrack = new \IPS\profilesongs\ProfileSongs;
			$newTrack->member_id = $member->member_id;
			$newTrack->location = $track->location;
			$newTrack->position = 0;
			$newTrack->name = $track->name;
			$newTrack->playlist_id = $member->member_id;
			$newTrack->save();
		}
		if( \IPS\Request::i()->isAjax() )
		{
			\IPS\Output::i()->json( 'OK' );
		}
	}
}